@@ -11,8 +11,9 @@ import chesney
 
 from wpdatabase2.classes import WpCredentials
 
-from wpbackup2.wpbackup import WpBackup
-from wpbackup2.wpsite import WpSite
+from wpbackup2.classes.wpbackup import WpBackup
+from wpbackup2.classes.wpsite import WpSite
+from wpbackup2.__version__ import __version__
 
 def run_from_cli():
     """
@@ -24,6 +25,9 @@ def run_from_cli():
                     'content.',
         prog='python -m wpbackup')
 
+    arg_parser.add_argument('--version', action='version',
+                    version='%(prog)s {version}'.format(version=__version__))
+
     arg_parser.add_argument('--backup',
                             action='store_true',
                             help='Perform a backup')
